#!/usr/bin/env python

import numpy
import matplotlib
from matplotlib import use
use('Agg')
import pylab

params =  {'text.usetex': True }
pylab.rcParams.update(params)

matplotlib.rcParams.update({
        "font.size": 7.0,
        "axes.titlesize": 7.0,
        "axes.labelsize": 7.0,
        "xtick.labelsize": 10.0,
        "ytick.labelsize": 10.0,
        "legend.fontsize": 7.0,
        "figure.figsize": (3,3),
        "figure.dpi": 600,
        "subplots.left": 0.05,
        "subplots.right": 0.05,
        "subplots.bottom": 0.05,
        "subplots.top": 0.05,
          "savefig.dpi": 600,
        "text.usetex": True     # render all text with TeX
})

## load files
physical_distance_highmass_setA=numpy.load('data/CBC_highmass_physical_distance_setA.npy')
physical_distance_CWB_setA=numpy.load('data/CWB_physical_distance_setA.npy')
physical_distance_CWB_setB=numpy.load('data/CWB_physical_distance_setB.npy')
physical_distance_Ringdown_setA=numpy.load('data/Ringdown_physical_distance_setA.npy')
physical_distance_Ringdown_setB=numpy.load('data/Ringdown_physical_distance_setB.npy')


smooth = numpy.arange(1,10000,1)

##############################
##### no interpolation #######
##############################

pylab.semilogx(physical_distance_highmass_setA[0], physical_distance_highmass_setA[2],"g:",lw=1,basex=10,label='IMR-templates')
pylab.errorbar(physical_distance_highmass_setA[0], physical_distance_highmass_setA[2], xerr=physical_distance_highmass_setA[1], yerr=physical_distance_highmass_setA[3],fmt='k.')
pylab.semilogx(physical_distance_CWB_setA[0], physical_distance_CWB_setA[2],"b-",lw=1,basex=10,label='CWB')
pylab.errorbar(physical_distance_CWB_setA[0], physical_distance_CWB_setA[2], xerr=physical_distance_CWB_setA[1], yerr=physical_distance_CWB_setA[3],fmt='k.')
pylab.semilogx(physical_distance_Ringdown_setA[0], physical_distance_Ringdown_setA[2],"r-.",lw=1,basex=10,label='Ringdown')
pylab.errorbar(physical_distance_Ringdown_setA[0], physical_distance_Ringdown_setA[2], xerr=physical_distance_Ringdown_setA[1], yerr=physical_distance_Ringdown_setA[3],fmt='k.')

pylab.grid(which='major')
pylab.grid(which='minor')
pylab.xlim(1,2000)
pylab.ylim(0,1.05)
pylab.legend(bbox_to_anchor=(0.95, 1), borderaxespad=0.,markerscale=2)
pylab.xlabel(r'Distance (Mpc)')
pylab.ylabel(r'Efficiency')	
pylab.savefig(r'figures/sigmoid_setA.png',bbox_inches='tight')
pylab.close()


#####################
pylab.semilogx(physical_distance_CWB_setB[0], physical_distance_CWB_setB[2],"b-",lw=1,basex=10,label='CWB')
pylab.errorbar(physical_distance_CWB_setB[0], physical_distance_CWB_setB[2], xerr=physical_distance_CWB_setB[1], yerr=physical_distance_CWB_setB[3],fmt='k.')
pylab.semilogx(physical_distance_Ringdown_setB[0], physical_distance_Ringdown_setB[2],"r-.",lw=1,basex=10,label='Ringdown')
pylab.errorbar(physical_distance_Ringdown_setB[0], physical_distance_Ringdown_setB[2], xerr=physical_distance_Ringdown_setB[1], yerr=physical_distance_Ringdown_setB[3],fmt='k.')

pylab.grid(which='major')
pylab.grid(which='minor')
pylab.xlim(1,2000)
pylab.ylim(0,1.05)
pylab.legend(bbox_to_anchor=(0.95, 1), borderaxespad=0.,markerscale=2)
pylab.xlabel(r'Distance (Mpc)')
pylab.ylabel(r'Efficiency')	
pylab.savefig(r'figures/sigmoid_setB.png',bbox_inches='tight')
pylab.close()


