import numpy
import matplotlib
matplotlib.use('Agg')
import pylab

params =  {'text.usetex': True }
pylab.rcParams.update(params)


matplotlib.rcParams.update({
        "font.size": 7.0,
        "axes.titlesize": 7.0,
        "axes.labelsize": 7.0,
        "xtick.labelsize": 10.0,
        "ytick.labelsize": 10.0,
        "legend.fontsize": 7.0,
        "figure.figsize": (3,3),
        "figure.dpi": 600,
	"subplots.left": 0.05,
	"subplots.right": 0.05,
        "subplots.bottom": 0.05,
        "subplots.top": 0.05,
        "savefig.dpi": 600,
        "text.usetex": True})


## load files
m_q_expected_range_setA=numpy.load('data/m_q_expected_range_setA.npy')
m_q_expected_range_setB=numpy.load('data/m_q_expected_range_setB.npy')
m_chi_expected_range_setA=numpy.load('data/m_chi_expected_range_setA.npy')
m_chi_expected_range_setB=numpy.load('data/m_chi_expected_range_setB.npy')


#################### set A : m vs q ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,m_q_expected_range_setA.T,vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(m_q_expected_range_setA[j,i])), (mass[j]+dm/1.8,q[i]+dq/1.6), color=[cv,cv,cv],size='large')



pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Expected Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_expected_range_color_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs chi ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,m_chi_expected_range_setA.T,vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(m_chi_expected_range_setA[j,i])), (mass[j]+dm/2.0,chi[i]+dchi/2.0), color=[cv,cv,cv],size='large')



pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Expected Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_expected_range_color_setA" + ".png",bbox_inches='tight')
pylab.close()




#################### set B : m vs q ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,m_q_expected_range_setB.T,vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(m_q_expected_range_setB[j,i])), (mass[j]+dm/1.8,q[i]+dq/1.6), color=[cv,cv,cv],size='large')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Expected Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_expected_range_color_setB" + ".png",bbox_inches='tight')
pylab.close()


#################### set B : m vs chi ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,m_chi_expected_range_setB.T,vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(m_chi_expected_range_setB[j,i])), (mass[j]+dm/2.0,chi[i]+dchi/2.0), color=[cv,cv,cv],size='large')



pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Expected Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_expected_range_color_setB" + ".png",bbox_inches='tight')
pylab.close()
