import numpy
import matplotlib
matplotlib.use('Agg')
import pylab

params =  {'text.usetex': True }
pylab.rcParams.update(params)


matplotlib.rcParams.update({
        "font.size": 7.0,
        "axes.titlesize": 7.0,
        "axes.labelsize": 7.0,
        "xtick.labelsize": 10.0,
        "ytick.labelsize": 10.0,
        "legend.fontsize": 7.0,
        "figure.figsize": (3,3),
        "figure.dpi": 600,
	"subplots.left": 0.05,
	"subplots.right": 0.05,
        "subplots.bottom": 0.05,
        "subplots.top": 0.05,
        "savefig.dpi": 600,
        "text.usetex": True})

## load files
IMR_templates_setA_m_q_sensitive=numpy.load('data/IMR-templates-setA-m_q_sensitive.npy')
IMR_templates_setA_m_chi_sensitive=numpy.load('data/IMR-templates-setA-m_chi_sensitive.npy')

Ringdown_setA_m_q_sensitive=numpy.load('data/Ringdown-setA-m_q_sensitive.npy')
Ringdown_setA_m_chi_sensitive=numpy.load('data/Ringdown-setA-m_chi_sensitive.npy')
Ringdown_setB_m_q_sensitive=numpy.load('data/Ringdown-setB-m_q_sensitive.npy')
Ringdown_setB_m_chi_sensitive=numpy.load('data/Ringdown-setB-m_chi_sensitive.npy')
CWB_setA_m_q_sensitive=numpy.load('data/CWB-setA-m_q_sensitive.npy')
CWB_setA_m_chi_sensitive=numpy.load('data/CWB-setA-m_chi_sensitive.npy')
CWB_setB_m_q_sensitive=numpy.load('data/CWB-setB-m_q_sensitive.npy')
CWB_setB_m_chi_sensitive=numpy.load('data/CWB-setB-m_chi_sensitive.npy')


#################### set A : m vs q : IMR-templates ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,IMR_templates_setA_m_q_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(IMR_templates_setA_m_q_sensitive[0].T[j,i])), (mass[j]+dm/2.8,q[i]+dq/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(IMR_templates_setA_m_q_sensitive[1].T[j,i])), (mass[i]+dm/2.2,q[j]+dq/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_sensitive_distance_IMR-templates_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs q : Ringdown ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,Ringdown_setA_m_q_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(Ringdown_setA_m_q_sensitive[0].T[j,i])), (mass[j]+dm/2.8,q[i]+dq/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(Ringdown_setA_m_q_sensitive[1].T[j,i])), (mass[i]+dm/2.2,q[j]+dq/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_sensitive_distance_Ringdown_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs q : CWB ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,CWB_setA_m_q_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(CWB_setA_m_q_sensitive[0].T[j,i])), (mass[j]+dm/2.8,q[i]+dq/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(CWB_setA_m_q_sensitive[1].T[j,i])), (mass[i]+dm/2.2,q[j]+dq/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_sensitive_distance_CWB_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs chi : IMR-templates ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,IMR_templates_setA_m_chi_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(IMR_templates_setA_m_chi_sensitive[0].T[j,i])), (mass[j]+dm/2.8,chi[i]+dchi/1.5), color=[cv,cv,cv],size='large')


for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(IMR_templates_setA_m_chi_sensitive[1].T[j,i])), (mass[i]+dm/2.2,chi[j]+dchi/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_sensitive_distance_IMR-templates_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs chi : Ringdown ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0


pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,Ringdown_setA_m_chi_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(Ringdown_setA_m_chi_sensitive[0].T[j,i])), (mass[j]+dm/2.8,chi[i]+dchi/1.5), color=[cv,cv,cv],size='large')


for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(Ringdown_setA_m_chi_sensitive[1].T[j,i])), (mass[i]+dm/2.2,chi[j]+dchi/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_sensitive_distance_Ringdown_setA" + ".png",bbox_inches='tight')
pylab.close()


#################### set A : m vs chi : CWB ##############################
mass = numpy.linspace(25.0,100.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(0.1,1.0,5)
dchi = (q[1]-q[0])/2.0

pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,CWB_setA_m_chi_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(CWB_setA_m_chi_sensitive[0].T[j,i])), (mass[j]+dm/2.8,chi[i]+dchi/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(CWB_setA_m_chi_sensitive[1].T[j,i])), (mass[i]+dm/2.2,chi[j]+dchi/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_sensitive_distance_CWB_setA" + ".png",bbox_inches='tight')
pylab.close()



#################### set B : m vs q : Ringdown ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0



pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,Ringdown_setB_m_q_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(Ringdown_setB_m_q_sensitive[0].T[j,i])), (mass[j]+dm/2.8,q[i]+dq/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(Ringdown_setB_m_q_sensitive[1].T[j,i])), (mass[i]+dm/2.2,q[j]+dq/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_sensitive_distance_Ringdown_setB" + ".png",bbox_inches='tight')
pylab.close()


#################### set B : m vs q : CWB ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
q = numpy.linspace(0.1,1.0,5)
dq = (q[1]-q[0])/2.0



pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,q,CWB_setB_m_q_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(str(int(CWB_setB_m_q_sensitive[0].T[j,i])), (mass[j]+dm/2.8,q[i]+dq/1.5), color=[cv,cv,cv],size='large')


for j in range(len(q)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(CWB_setB_m_q_sensitive[1].T[j,i])), (mass[i]+dm/2.2,q[j]+dq/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$q$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(q), max(q)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_q_sensitive_distance_CWB_setB" + ".png",bbox_inches='tight')
pylab.close()



#################### set B : m vs chi : Ringdown ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0



pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,Ringdown_setB_m_chi_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(Ringdown_setB_m_chi_sensitive[0].T[j,i])), (mass[j]+dm/2.8,chi[i]+dchi/1.5), color=[cv,cv,cv],size='large')


for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(Ringdown_setB_m_chi_sensitive[1].T[j,i])), (mass[i]+dm/2.2,chi[j]+dchi/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_sensitive_distance_Ringdown_setB" + ".png",bbox_inches='tight')
pylab.close()


#################### set B : m vs chi : CWB ##############################
mass = numpy.linspace(100.0,350.0,5)
dm = (mass[1]-mass[0])/2.0
chi = numpy.linspace(-0.85,0.85,5)
dchi = (chi[1]-chi[0])/2.0



pylab.hot()
ax=pylab.subplot()
pylab.pcolor(mass,chi,CWB_setB_m_chi_sensitive[0],vmin=0, vmax=200,label='Sensitive Range (Mpc)')

cv = 0
for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(str(int(CWB_setB_m_chi_sensitive[0].T[j,i])), (mass[j]+dm/2.8,chi[i]+dchi/1.5), color=[cv,cv,cv],size='large')


for j in range(len(chi)):
    for i in range(len(mass)):
        ax.annotate(r'$\pm$'+ str(int(CWB_setB_m_chi_sensitive[1].T[j,i])), (mass[i]+dm/2.2,chi[j]+dchi/5.), color=[cv,cv,cv],size='small')


pylab.xlabel(r"$M$" + " $\mathrm{(M_{\odot})}$",fontsize=8,weight="bold")
pylab.ylabel(r"$\chi_{s}$",fontsize=8,weight="bold")

pylab.xlim([min(mass), max(mass)])
pylab.ylim([min(chi), max(chi)])
levsticks = numpy.array([0,100,200])
cb = pylab.colorbar(orientation='horizontal',fraction=0.09,shrink=0.5,ticks=levsticks)
cb.set_label(r'Sensitive Distance (Mpc)',fontsize=7,weight='bold')
pylab.savefig("figures/m_chi_sensitive_distance_CWB_setB" + ".png",bbox_inches='tight')
pylab.close()
